# OSINTBuddy plugins and extensions

The plugins library for [jerlendds/osintbuddy](https://github.com/jerlendds/osintbuddy), coming soon...

## Extending OSINTBuddy with extensions/plugins

@todo

## Creating an extension thats dependent on other plugins...

@todo

## Creating custom nodes

